@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_YY_PARSER_H_INCLUDED
-# define YY_YY_PARSER_H_INCLUDED
+#ifndef YY_YY_SRC_LIBOCONFIG_PARSER_H_INCLUDED
+# define YY_YY_SRC_LIBOCONFIG_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -72,7 +72,7 @@ extern int yydebug;
 typedef union YYSTYPE YYSTYPE;
 union YYSTYPE
 {
-#line 47 "parser.y" /* yacc.c:1909  */
+#line 47 "src/liboconfig/parser.y" /* yacc.c:1909  */
 
 	double  number;
 	int     boolean;
@@ -82,7 +82,7 @@ union YYSTYPE
 	argument_list_t  al;
 	statement_list_t sl;
 
-#line 86 "parser.h" /* yacc.c:1909  */
+#line 86 "src/liboconfig/parser.h" /* yacc.c:1909  */
 };
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
@@ -93,4 +93,4 @@ extern YYSTYPE yylval;
 
 int yyparse (void);
 
-#endif /* !YY_YY_PARSER_H_INCLUDED  */
+#endif /* !YY_YY_SRC_LIBOCONFIG_PARSER_H_INCLUDED  */
